Rust port of the slc replay format for Geometry Dash.
Provides a compact and fast replay format to use for bots and converters. Silicate’s official format.
Re-exports
pub use input::PlayerData;Deprecated pub use input::Input;pub use input::InputData;pub use input::PlayerInput;pub use meta::Meta;pub use replay::Replay;pub use replay::ReplayError;